==> ejc-proequipmentp-impl-3.0.0-20220715.081248-185-sources.jar: com/ejianc/business/purchaseplan/bean/PurchasePlanDetailedEntity.java <==
package com.ejianc.business.purchaseplan.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 购置计划-计划清单表
 *
 * @author generator
 *
 */
@TableName("ejc_proequipment_purchase_plan_detailed")
public class PurchasePlanDetailedEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="code")
    private String code; // 序号
    @TableField(value="equipment_type")
    private String equipmentType; // 设备类别
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="company")
    private String company; // 单位
    @TableField(value="plan_num")
    private Long planNum; // 计划购置数量
    @TableField(value="estimate_price")
    private BigDecimal estimatePrice; // 预计单价
    @TableField(value="estimate_amount")
    private BigDecimal estimateAmount; // 预计金额
    @TableField(value="estimate_purchase_date")
    private Date estimatePurchaseDate; // 预计购置时间
    @TableField(value="manufacturer")
    private String manufacturer; // 生产厂家
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="source_type")
    private String sourceType; // 来源类型
    @TableField(value="plan_id")
    private Long planId; // 所属计划Id(计划表主键相当于pid)
    @TableField(value="doc_category_id")
    private Long docCategoryId; // 档案分类id
    @TableField(value="doc_id")
    private Long docId; // 档案Id
    @TableField(value="tid")
    private Long tid; // 上级id
    @TableField(value="parent_id")
    private Long parentId; // 父类id
    @TableField(value="leaf_flag")
    private Boolean leafFlag; //
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码




    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getEquipmentType() {
        return equipmentType;
    }

    public void setEquipmentType(String equipmentType) {
        this.equipmentType = equipmentType;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }
    public Long getPlanNum() {
        return planNum;
    }

    public void setPlanNum(Long planNum) {
        this.planNum = planNum;
    }
    public BigDecimal getEstimatePrice() {
        return estimatePrice;
    }

    public void setEstimatePrice(BigDecimal estimatePrice) {
        this.estimatePrice = estimatePrice;
    }
    public BigDecimal getEstimateAmount() {
        return estimateAmount;
    }

    public void setEstimateAmount(BigDecimal estimateAmount) {
        this.estimateAmount = estimateAmount;
    }
    public Date getEstimatePurchaseDate() {
        return estimatePurchaseDate;
    }

    public void setEstimatePurchaseDate(Date estimatePurchaseDate) {
        this.estimatePurchaseDate = estimatePurchaseDate;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public Long getDocCategoryId() {
        return docCategoryId;
    }

    public void setDocCategoryId(Long docCategoryId) {
        this.docCategoryId = docCategoryId;
    }
    public Long getDocId() {
        return docId;
    }

    public void setDocId(Long docId) {
        this.docId = docId;
    }
    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public Boolean getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
}

==> ejc-proequipmentp-impl-3.0.0-20221117.064921-304-sources.jar: com/ejianc/business/purchaseplan/bean/PurchasePlanDetailedEntity.java <==
package com.ejianc.business.purchaseplan.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 购置计划-计划清单表
 *
 * @author generator
 *
 */
@TableName("ejc_proequipment_purchase_plan_detailed")
public class PurchasePlanDetailedEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="code")
    private String code; // 序号
    @TableField(value="equipment_type")
    private String equipmentType; // 设备类别
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="company")
    private String company; // 单位
    @TableField(value="plan_num")
    private Long planNum; // 计划购置数量
    @TableField(value="estimate_price")
    private BigDecimal estimatePrice; // 预计单价
    @TableField(value="estimate_amount")
    private BigDecimal estimateAmount; // 预计金额
    @TableField(value="estimate_purchase_date")
    private Date estimatePurchaseDate; // 预计购置时间
    @TableField(value="manufacturer")
    private String manufacturer; // 生产厂家
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="source_type")
    private String sourceType; // 来源类型
    @TableField(value="plan_id")
    private Long planId; // 所属计划Id(计划表主键相当于pid)
    @TableField(value="doc_category_id")
    private Long docCategoryId; // 档案分类id
    @TableField(value="doc_id")
    private Long docId; // 档案Id
    @TableField(value="tid")
    private Long tid; // 上级id
    @TableField(value="parent_id")
    private Long parentId; // 父类id
    @TableField(value="leaf_flag")
    private Boolean leafFlag; //
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码

    @TableField(value="remaining_num")
    private Long remainingNum; // 剩余可申请数量


    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getEquipmentType() {
        return equipmentType;
    }

    public void setEquipmentType(String equipmentType) {
        this.equipmentType = equipmentType;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getCompany() {
        return company;
    }

    public void setCompany(String company) {
        this.company = company;
    }
    public Long getPlanNum() {
        return planNum;
    }

    public void setPlanNum(Long planNum) {
        this.planNum = planNum;
    }
    public BigDecimal getEstimatePrice() {
        return estimatePrice;
    }

    public void setEstimatePrice(BigDecimal estimatePrice) {
        this.estimatePrice = estimatePrice;
    }
    public BigDecimal getEstimateAmount() {
        return estimateAmount;
    }

    public void setEstimateAmount(BigDecimal estimateAmount) {
        this.estimateAmount = estimateAmount;
    }
    public Date getEstimatePurchaseDate() {
        return estimatePurchaseDate;
    }

    public void setEstimatePurchaseDate(Date estimatePurchaseDate) {
        this.estimatePurchaseDate = estimatePurchaseDate;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public Long getDocCategoryId() {
        return docCategoryId;
    }

    public void setDocCategoryId(Long docCategoryId) {
        this.docCategoryId = docCategoryId;
    }
    public Long getDocId() {
        return docId;
    }

    public void setDocId(Long docId) {
        this.docId = docId;
    }
    public Long getTid() {
        return tid;
    }

    public void setTid(Long tid) {
        this.tid = tid;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public Boolean getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    public Long getRemainingNum() {
        return remainingNum;
    }

    public void setRemainingNum(Long remainingNum) {
        this.remainingNum = remainingNum;
    }
}
